@@ -163,7 +163,7 @@ class SoapController(controllers.Controller):
         faultstring.append(str(e))
         fault.append(faultstring)
         
-        cherrypy.response.headers["Content-Type"] = "text/xml;charset=utf-8"
+        cherrypy.response.headers["Content-Type"] = "text/xml"
         
         # customize the fault for the type of problem
         if isinstance(e, validators.Invalid):
@@ -185,7 +185,7 @@ class SoapController(controllers.Controller):
         cherrypy.response.body = str(envelope)
     
     @tgexpose("genshi:tgwebservices.templates.soap",
-              content_type="application/soap+xml;charset=utf-8", format="xml")
+              content_type="application/soap+xml", format="xml")
     def index(self):
         """Processes SOAP requests and generates the responses."""
         # get request data and produce an ElementTree that we can work with.
@@ -230,7 +230,7 @@ class SoapController(controllers.Controller):
         return data
     
     @tgexpose("genshi:tgwebservices.templates.wsdl", format="xml",
-              content_type="text/xml;charset=utf-8")
+              content_type="text/xml")
     def api_wsdl(self, xmlsoap=False):
         """Produces the WSDL for this SOAP service."""
         if self.arrays is None:
