@@ -40,6 +40,9 @@ class ReadWriteProperty(object):
         return self._value
     value = typedproperty(str, getvalue, setvalue)
 
+    # This normal property will not be considered
+    rawvalue = property(getvalue, setvalue)
+
 class FoodItem(object):
     person = FancyValue
     quantity = unsigned
